@@ -10,15 +10,10 @@
   cat('o        Register on                                              o',fill=TRUE)
   cat('o        http://folk.uio.no/gillesg/Geneland/register.php         o',fill=TRUE)
   cat('o                                                                 o',fill=TRUE)  
-  cat('o        See                                                      o',fill=TRUE)
+  cat('o        See manual on                                            o',fill=TRUE)
   cat('o        http://folk.uio.no/gillesg/Geneland/Geneland.html        o',fill=TRUE)  
-  cat('o        for a quick introduction.                                o',fill=TRUE)
   cat('o                                                                 o',fill=TRUE)
-  cat('o        See also                                                 o',fill=TRUE)
-  cat('o        http://folk.uio.no/gillesg/Geneland/faq.html             o',fill=TRUE)
-  cat('o        for frequently asked questions.                          o',fill=TRUE)
-  cat('o                                                                 o',fill=TRUE)
-  cat('o       This is Geneland-3.1.0                                    o',fill=TRUE)
+  cat('o        This is Geneland-3.1.2                                   o',fill=TRUE)
   cat('o                                                                 o',fill=TRUE)
   cat('ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo',fill=TRUE)
 }
