@@ -11,6 +11,9 @@ void F77_SUB(rndstart)(void)
 void F77_SUB(rndend)(void) 
 { PutRNGstate(); }
 
+void F77_SUB(ggrmultinom)(int n, double* prob, int K, int* rN)
+{ rmultinom(n, prob, K, rN); }
+
 double F77_SUB(ggrnorm)(double *mu, double *sigma) 
 { return rnorm(*mu, *sigma); }
 
@@ -20,6 +23,9 @@ double F77_SUB(ggrexp)(double *scale)
 double F77_SUB(ggrgam)(double *a, double *scale)
 {return rgamma(*a, *scale);}
 
+double F77_SUB(ggrbet)(double *a, double *b)
+{return rbeta(*a, *b);}
+
 double F77_SUB(ggrunif)(double *a, double *b)
 {return runif(*a, *b);}
 
@@ -30,16 +36,19 @@ double F77_SUB(ggrpois)(double *lambda)
 {return rpois(*lambda);}
 
 
+
+
+
 /*********************/
 /* special functions */
 /*********************/
 
 /* gamma function  */
-double F77_SUB(gggammafn)(double *x) 
+double F77_SUB(gggamfn)(double *x) 
 { return gammafn(*x); }
 
 /* log of gamma function */
-double F77_SUB(gglgammafn)(double *x) 
+double F77_SUB(gglgamfn)(double *x) 
 { return lgammafn(*x); }
 
 /* Bessel K  */
